#
# spec file for package calls
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           calls
Version:        47.0
Release:        1.4
Summary:        A phone dialer and call handler
License:        GPL-3.0-only AND MIT
URL:            https://gitlab.gnome.org/GNOME/calls
Source0:        %{name}-%{version}.tar.zst
BuildRequires:  appstream-glib
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-docutils
BuildRequires:  sofia-sip
BuildRequires:  vala
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(folks)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gom-1.0)
BuildRequires:  pkgconfig(gsound)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libcallaudio-0.1)
BuildRequires:  pkgconfig(libebook-contacts-1.2)
BuildRequires:  pkgconfig(libfeedback-0.0)
BuildRequires:  pkgconfig(libpeas-2)
BuildRequires:  pkgconfig(mm-glib)
BuildRequires:  pkgconfig(sofia-sip-ua-glib)

%description
%{summary}.

Calls is also a capable sip-client.

%package ofono
Summary:        Ofono support for %{name}
Requires:       %{name} = %{version}

%description ofono
%{summary}.

This package is not recommended, only install if you are sure you
want ofono support.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	--sysconfdir=%{_distconfdir} \
	-Dsystemd_user_unit_dir=%{_userunitdir} \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%find_lang call-ui %{?no_lang_C}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Calls.metainfo.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Calls.desktop

## Some tests are failing in the build environment, so we manually just run a handful for now.
#LC_ALL=C.UTF-8 xvfb-run sh <<'SH'
#%%meson_test manager plugins
#SH

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/gnome-%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/provider
%dir %{_libdir}/%{name}/plugins/provider/mm
%dir %{_libdir}/%{name}/plugins/provider/dummy
%dir %{_libdir}/%{name}/plugins/provider/sip
%{_libdir}/%{name}/plugins/provider/mm/libmm.so
%{_libdir}/%{name}/plugins/provider/mm/mm.plugin
%{_libdir}/%{name}/plugins/provider/dummy/dummy.plugin
%{_libdir}/%{name}/plugins/provider/dummy/libdummy.so
%{_libdir}/%{name}/plugins/provider/sip/libsip.so
%{_libdir}/%{name}/plugins/provider/sip/sip.plugin
# ofono is dead upstream so we explicitly exclude the plugins from main package
%exclude %{_libdir}/%{name}/plugins/provider/ofono/libofono.so
%exclude %{_libdir}/%{name}/plugins/provider/ofono/ofono.plugin
%{_datadir}/glib-2.0/schemas/org.gnome.Calls.gschema.xml
%{_datadir}/applications/org.gnome.Calls.desktop
%{_datadir}/dbus-1/services/org.gnome.Calls.service
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Calls.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Calls-symbolic.svg
%{_datadir}/metainfo/org.gnome.Calls.metainfo.xml
%{_mandir}/man1/gnome-calls.1%{?ext_man}
%{_distconfdir}/xdg/autostart/org.gnome.Calls-daemon.desktop
%{_userunitdir}/calls-daemon.service

%files ofono
%dir %{_libdir}/%{name}/plugins/provider/ofono
%{_libdir}/%{name}/plugins/provider/ofono/libofono.so
%{_libdir}/%{name}/plugins/provider/ofono/ofono.plugin

%files lang -f %{name}.lang -f call-ui.lang

%changelog
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Clear number and address entries when closing the application
    window
  + Fix crash on mobile when placing outgoing call
  + Fix keypad layout in RTL locales
  + Updated translations.
- Changes from version 47.rc:
  + Now uses AdwAboutDialog, requiring Adwaita 1.5
  + Improved style sheets
  + Actually shipping translated metainfo
- Changes from version 47.beta:
  + Add systemd unit file
  + Emit phone-hangup event
  + libpeas-2 port
- Changes from version 47.alpha:
  + GTK4 Port
  + Fix crash when Modem has no location services
  + Fix crash when SIP handles have never gotten set up
- Changes in BuildRequires following upstreams porting:
  + Add pkgconfig(libadwaita-1), pkgconfig(libpeas-2) and
    pkgconfig(gtk4)
  + Drop pkgconfig(gtk+-3.0), pkgconfig(libhandy-1) and
    pkgconfig(libpeas-1.0)
* Sat Jun 29 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.3:
  + Fix crash when Modem has no location services.
  + Fix crash when SIP handles have never gotten set up.
  + Updated translations.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Metainfo improvements.
  + Add available emergency numbers by location (country code).
  + Fix call back button being insensitive.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
* Fri Sep 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Updated translations.
* Mon Sep  4 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.rc.0:
  + New SIP feature: Support for AES 256 bit crypto suites.
  + Fixed object life cycle of CallsMMOrigin.
  + Updated translations.
- Changes from version 45.alpha.0:
  + New features:
  - Emergency call numbers provided through ModemManager.
  - Resolve emergency number types using hardcoded table.
  + Don't crash on empty/NULL call id.
  + Properly unregister SIP account on shutdown.
  + A couple of memory leaks.
  + Updated libcall-ui to bring in latest fixes and translation
    updates.
  + Updated translations.
* Sun Jun 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Fix origin being unrefed making calling impossible after a few
    of calls.
* Sat Apr 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Don't crash on empty/NULL call id
  + Properly unregister SIP account on shutdown
  + A couple of memory leaks
  + Updated libcall-ui to bring in latest fixes
  + Updated translations.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + New features:
  - Sort favourite contacts at the top.
  - Support for emergency calls in "dummy" provider.
  + Maybe noteworthy:
  - Fixed a couple of memory leaks.
  - Higher code coverage.
  - Disable call waiting.
  + Updated translations.
* Tue Mar  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.alpha.1:
  + **Really** fix endless ringing bug
  + Fixed a crash
  + Database closed correctly on shutdown
  + Updated translations.
- Changes from version 44.alpha.0:
  + Fixed rare endless ringing bug (requires feedbackd 0.0.1)
  + SIP: Honour remote port in INVITE
  + SIP: Reenable G722 codec
  + Shuts down gracefully on SIGTERM/SIGINT
  + Flatpak build improvements
  + Updated translations.
* Thu Jan 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.3:
  + **Really** fix endless ringing bug.
  + Fixed a crash.
  + Database closed correctly on shutdown.
  + Allow building without GStreamer debugging API.
  + Updated translations.
* Mon Dec  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Fixed rare endless ringing bug (requires feedbackd 0.0.1).
  + SIP: Honour remote port in INVITE.
  + SIP: Reenable G722 codec.
  + Shuts down gracefully on SIGTERM/SIGINT.
  + Flatpak build improvements.
  + Updated translations.
* Mon Sep 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Update libcall-ui to always reset audio profile.
  + i18n: mm-call: Clarify "transfer" and "deflect".
  + tests: Remove unused code.
  + metainfo: Correct screenshot URLs.
  + Updated translations.
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc.0:
  + New features: Call display redesigned.
  + Maybe noteworthy:
  - Changed the default branch to "main".
  - Fix auto-connect VoIP setting not being honored.
  - Fixed issue with outgoin waiting calls considered as incoming
    call.
  + Updated translations.
* Fri Aug 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.beta.0:
  + Improved startup times and scrolling performance with large
    call histories.
  + Add "Send SMS" action in history popover
- Changes from version 43.alpha.2:
  + Calls is now DBus activatable.
  + Made debug logs more meaningful.
  + Added manpage using rst2man.
  + Bumped delay until UI is shown to 100ms.
  + Indicate we're using feedbackd in desktop file which is useful
    for phosh-mobile-settings.
- Changes from version 43.alpha.1:
  + SIP plugin can now be used for SRTP (SDES key exchange).
    By default it can only be used when using TLS transport.
    If you want to use SRTP without TLS, you must set the newly
    added "always-allow-sdes" gsetting.
- Changes from version 43.alpha.0:
  + Preparations for allowing use of SRTP (not user-visible).
  + Added switch to display password in VoIP account management.
  + Updated translations.
- Switch from _service to upstream released tarballs.
- Add python3-docutils BuildRequires: allow to build man pages.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Sun Mar  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc.1:
  + G722 is now the preferred codec for SIP calls.
  + Hole punching scheme now also used for RTCP.
  + Updated translations.
* Fri Feb 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc0:
  + Bugfix release
  + Updated libcall-ui to v0.0.2
  + Call time now in sync with phosh (phosh 0.16.0 required)
  + Updated translations.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta.1:
  + Bugfix release
  + Updated libcall-ui to v0.0.1
- Changes from version 42.beta.0:
  + New features:
  - SIP providers can now handle tel URIs
  - Allow adding contacts from call history
  + Maybe noteworthy:
  - In app feedback when SIP accounts go online/offline
  - Can set preferred audio codecs via gsetting
- Changes from version 42.alpha.0:
  + New features:
  - Avatars in the call history and call display
  - Avatars exposed over DBus so phosh show them on the lockscreen
  - Can silence ringing over DBus (used in phosh-antispam
  + Maybe noteworthy:
  - Note to distribution packagers: Both Calls and current phosh
    (0.14.1) are embedding libcall-ui which will install
    translation files (typically installed to
    /usr/share/locale/*/LC_MESSAGES/call-ui.mo). The next phosh
    version will default to not installing i18n files of
    libcall-ui (World/Phosh/phosh!963). For this version you
    should either cherry pick World/Phosh/phosh@b51e2001 or
    exclude call-ui.mo when installing phosh's translations in
    your packaging.
  - Improved scrolling performance in the call history
  - Can use DTMF over DBus (used in phosh on the lockscreen)
  - Various UI fixes
  + Updated translations.
- Pass sysconfdir=%%%%{_distconfdir} to meson, install autostart
  desktop file to /usr/etc/
- Split out a new sub package calls-ofono, and package the
  deprecated ofono support should some endusers still want to use
  it.
* Mon Jan 31 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Tidy the spec up even more, use generic BuildRequires for
  compilers needed, update URL to current home.
- Run selective tests only.
- Exclude packaging of ofono plugins, upstream is gone/defunct.
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.1:
  + Quite a lot of changes and stabilisation work since 0.3.4.
- Change _service to grab source from gitlab.gnome.org.
* Sun Jun 27 2021 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.3.4
  * manager: Set peas search path only once
  * provider: whitespace and indentation
  * cleanup: Fix calls_origin_get_name() related memory leaks
  * mm: origin: Try using own number as the origin name
  * account-provider: Add debugging in the public functions
  * plugins: provider: Use CallsOrigin instead of derived types for GListStore
  * util: Add simple API to query protocol
  * test: Add util tests
  * call: Introduce protocol property
  * calls-record: Introduce the protocol property
  * provider: Add API to query supported protocols
  * origin: Add API to query supported protocols
  * manager: support multiple providers
  * application: Add CallsSettings class
  * new-call-box: Honour auto-use-default-origins setting
  * application: Don't add a provider if one is already present
  * manager: Differentiate the NO_ORIGIN state
  * test: manager: Use more appropriate `g_assert_*()` calls
  * sip: provider: Don't warn when trying to add account multiple times
  * tests: manager: Add multiple provider tests
  * application: settings: Add country code setting
  * manager: Update country code
  * ci: disable flatpak build
  * d/control: Add libxml2-utils
  * meson: Compile schemas in build directory
  * Add run script to the build directory
  * Update README: Explain how to start calls without installing
  * Initial DBus API
  * display: codestyle
  * display: Fix typo
  * record-store: codestyle
  * Fix old-style warnings all over the codebase
  * Fix missing-declarations warnings all over the codebase
  * sip: media-pipeline: Don't shadow props variable
  * ofono: call: Don't shadow props variable
  * mm: origin: Don't shadow props variable
  * call-display: Add default case to switch statement
  * record-store: Add default case to switch statements
  * main-window: Add default case to switch statement
  * meson: Use stricter compilation warnings and errors
  * desktop-file: Register as sip and sips URI scheme handler
  * run: Add plugin search directory
  * README: Reword plugin search directory section to be more accurate
  * dir-locals: Treat G_* macros as including a semicolon
  * manager: Fix whitespace
  * manager: codestyle
  * sip: origin: Fix if condition in dispose()
  * util: Make position argument in calls_find_store() optional
  * test: manager: Expanded *has_provider() testing
* Wed Apr 28 2021 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.3.2
* Sun Apr 11 2021 Andrés B.S. <andresbs@opensuse.org>
- Tweaks to packaging
* Thu Dec 17 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.1.9
* Mon Oct  5 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.1.8
* Sun Jul 26 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.1.7 with patches for openSUSE
* Sat Jun 20 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.1.4.
* Sun Feb 23 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Updating version 0.3.1
